==> broker-amqp-1.0.1-sources.jar: org/wso2/broker/amqp/codec/frames/ExchangeDeclareOk.java <==
/*
 * Copyright (c) 2017, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * WSO2 Inc. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.wso2.broker.amqp.codec.frames;

import io.netty.buffer.ByteBuf;
import io.netty.channel.ChannelHandlerContext;
import org.wso2.broker.amqp.codec.AmqpConnectionHandler;

/**
 * AMQP frame for exchange.declare-ok
 * Parameter Summary:
 *     No parameters
 */
public class ExchangeDeclareOk extends MethodFrame {

    public ExchangeDeclareOk(int channel) {
        super(channel, (short) 40, (short) 11);
    }

    @Override
    protected long getMethodBodySize() {
        return 0L;
    }

    @Override
    protected void writeMethod(ByteBuf buf) {
    }

    @Override
    public void handle(ChannelHandlerContext ctx, AmqpConnectionHandler connectionHandler) {
        // Server does not handle exchange.declare-ok frame
    }

    public static AmqMethodBodyFactory getFactory() {
        return (buf, channel, size) -> new ExchangeDeclareOk(channel);
    }
}

==> broker-amqp-1.0.29-sources.jar: org/wso2/broker/amqp/codec/frames/ExchangeDeclareOk.java <==
/*
 * Copyright (c) 2017, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * WSO2 Inc. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.wso2.broker.amqp.codec.frames;

import io.netty.buffer.ByteBuf;
import io.netty.channel.ChannelHandlerContext;
import org.wso2.broker.amqp.codec.AmqpConnectionHandler;

/**
 * AMQP frame for exchange.declare-ok.
 * Parameter Summary:
 *     No parameters
 */
public class ExchangeDeclareOk extends MethodFrame {

    public ExchangeDeclareOk(int channel) {
        super(channel, (short) 40, (short) 11);
    }

    @Override
    protected long getMethodBodySize() {
        return 0L;
    }

    @Override
    protected void writeMethod(ByteBuf buf) {
    }

    @Override
    public void handle(ChannelHandlerContext ctx, AmqpConnectionHandler connectionHandler) {
        // Server does not handle exchange.declare-ok frame
    }

    public static AmqMethodBodyFactory getFactory() {
        return (buf, channel, size) -> new ExchangeDeclareOk(channel);
    }
}
